=== modified file 'config.yaml'
--- config.yaml	2013-01-28 20:11:56 +0000
+++ config.yaml	2013-01-28 20:21:00 +0000
@@ -54,10 +54,6 @@
         description: |
           The web site secret key. Leave empty will generate one (Note: you don't
           want that in a multi-unit architechture).
-    wsgi_worker_class:
-        type: string
-        default: "sync"
-        description: Gunicorn workers type. This variable can't be changed after installation.
     swift_auth_url:
         type: string
         default: ""
@@ -82,3 +78,82 @@
         type: string
         default: ''
         description: Swift container name
+    wsgi_wsgi_file:
+        type: string
+        description: "The name of the WSGI application."
+    wsgi_workers:
+        type: int
+        default: 2
+        description: "The number of worker process for handling requests."
+    wsgi_worker_class:
+        type: string
+        default: "sync"
+        description: "Gunicorn workers type."
+    wsgi_worker_connections:
+        type: int
+        default: 1000
+        description: "The maximum number of simultaneous clients."
+    wsgi_max_requests:
+        type: int
+        default: 0
+        description: "The maximum number of requests a worker will process before restarting."
+    wsgi_backlog:
+        type: int
+        default: 2048
+        description: "The maximum number of pending connections."
+    wsgi_timeout:
+        type: int
+        default: 30
+        description: ""
+    wsgi_keep_alive:
+        type: int
+        default: 2
+        description: ""
+    wsgi_umask:
+        type: string
+        default: "0"
+        description: "A bit mask for the file mode on files written by Gunicorn. The number 0 means Python guesses the base. Note that this affects unix socket permissions."
+    wsgi_user:
+        type: string
+        default: "www-data"
+        description: "Switch worker processes to run as this user. User id (as an int) or the name."
+    wsgi_group:
+        type: string
+        default: "www-data"
+        description: "Switch worker process to run as this group. A valid group id (as an int) or the name."
+    wsgi_log_file:
+        type: string
+        default: "-"
+        description: "The log file to write to. If empty the file would be <your_application_dir>/gunicorn.log"
+    wsgi_log_level:
+        type: string
+        default: "info"
+        description: "The granularity of Error log outputs."
+    wsgi_access_logfile:
+        type: string
+        default: "-"
+        description: "The Access log file to write to."
+    wsgi_access_logformat:
+        type: string
+        default: '%(h)s %(l)s %(u)s %(t)s "%(r)s" %(s)s %(b)s "%(f)s" "%(a)s"'
+        description: "The Access log format ."
+    wsgi_extra:
+        type: string
+        default: ""
+        description: "Extra settings. For example: {--debug},"
+    wsgi_timestamp:
+        type: string
+        default: ""
+        description: "The variable to modify to trigger Gunicorn reload"
+    django_settings:
+        type: string
+        default: ""
+        description: "The Python path to a Django settings module."
+    python_path:
+        type: string
+        default: ""
+        description: "Set PYTHONPATH environment variable"
+    port:
+        type: int
+        default: 8080
+        description: "Default listen port"

=== modified file 'hooks/wsgi-relation-joined'
--- hooks/wsgi-relation-joined	2012-07-06 16:02:20 +0000
+++ hooks/wsgi-relation-joined	2013-01-24 19:50:26 +0000
@@ -5,7 +5,15 @@
 
 relation-set working_dir="/srv/${UNIT_NAME}/"
 
-# The best would be to set all variables that starts with wsgi_
-relation-set wsgi_file="wsgi"
-relation-set wsgi_worker_class=$(config-get wsgi_worker_class)
+variables="wsgi_wsgi_file wsgi_workers wsgi_worker_class wsgi_worker_connections wsgi_max_requests wsgi_timeout wsgi_backlog wsgi_keep_alive wsgi_extra wsgi_user wsgi_group wsgi_umask wsgi_log_file wsgi_log_level wsgi_access_logfile wsgi_access_logformat env_extra django_settings python_path port"
+
+declare -A VAR
+for v in $variables;do
+  VAR[$v]=$(config-get $v)
+  if [ ! -z "${VAR[$v]}" ] ; then
+    relation-set "$v=${VAR[$v]}"
+  fi
+done
+
+juju-log "Set relation variables: ${VAR[@]}"
 

